Models
======

lda\_over\_time.models.lda\_seq\_model
--------------------------------------

.. automodule:: lda_over_time.models.lda_seq_model
   :members:
   :undoc-members:
   :show-inheritance:

lda\_over\_time.models.temporal\_lda\_model
-------------------------------------------

.. automodule:: lda_over_time.models.temporal_lda_model
   :members:
   :undoc-members:
   :show-inheritance:
